@@ -4,3 +4,5 @@ from .program import Program
 from .program_scope import ProgramScope
 from .domain import Domain
 from .domains import Domains
+from .notification import Notification
+from .notifications import Notifications
