@@ -29,8 +29,12 @@ Please use https://github.com/bugbountyrecon/bbrecon/issues to report issues.
 )
 configure = typer.Typer(help="Configure bbrecon.")
 get = typer.Typer(help="Fetch resources.")
+delete = typer.Typer(help="Delete resources.")
+create = typer.Typer(help="Create resources.")
 app.add_typer(get, name="get")
+app.add_typer(delete, name="delete")
 app.add_typer(configure, name="configure")
+app.add_typer(create, name="create")
 
 
 class InvalidDateInputError(Exception):
@@ -150,6 +154,43 @@ def output_narrow_domains_table(domains: List[Domain]):
 output_wide_domains_table = output_narrow_domains_table
 
 
+def output_json_notifications_table(notifications: List[Domain]):
+    typer.echo(
+        json.dumps([notification.to_dict() for notification in notifications], indent=4)
+    )
+
+
+def output_narrow_notifications_table(notifications: List[Domain]):
+    headers = ["ID", "RESOURCES", "TARGET", "MEDIUM"]
+    data = []
+    for notification in notifications:
+        data.append(
+            [
+                notification.id,
+                notification.resources,
+                notification.target,
+                notification.medium,
+            ]
+        )
+    typer.echo(tabulate(data, headers, tablefmt="plain"))
+
+
+def output_wide_notifications_table(notifications: List[Domain]):
+    headers = ["ID", "RESOURCES", "TARGET", "MEDIUM", "DESTINATION"]
+    data = []
+    for notification in notifications:
+        data.append(
+            [
+                notification.id,
+                notification.resources,
+                notification.target,
+                notification.medium,
+                notification.destination,
+            ]
+        )
+    typer.echo(tabulate(data, headers, tablefmt="plain"))
+
+
 @get.command("programs")
 def programs_get(
     program_slugs: Optional[List[str]] = typer.Argument(None),
@@ -325,12 +366,86 @@ format '%Y-%m-%d' can be supplied. Alternatively, the following keywords are sup
     globals()[f"output_{output}_domains_table"](domains)
 
 
+@get.command("notifications")
+def notifications_get(
+    notification_ids: Optional[List[str]] = typer.Argument(None),
+    output: OutputFormat = typer.Option(
+        OutputFormat.wide, "--output", "-o", help="Output format."
+    ),
+):
+    """
+    Display many notifications, in a table or as JSON.
+    """
+
+    try:
+        if notification_ids:
+            notifications = list(bb.notification(id=id) for id in notification_ids)
+        else:
+            notifications = list(bb.notifications())
+    except ApiResponseError as e:
+        typer.echo(e)
+        exit()
+
+    globals()[f"output_{output}_notifications_table"](notifications)
+
+
+@delete.command("notifications")
+def notifications_delete(notification_ids: Optional[List[str]] = typer.Argument(None)):
+    """
+    Delete one or more notifications.
+    """
+
+    try:
+        for id in notification_ids:
+            bb.delete_notification(id=id)
+            typer.echo(f"Successfully deleted notification '{id}'.")
+    except ApiResponseError as e:
+        typer.echo(e)
+        exit()
+
+
+@create.command("notifications")
+def notifications_create(
+    resources: str = typer.Option(
+        ..., "--resources", help="Resources to monitor. Currently supports 'programs'.",
+    ),
+    target: str = typer.Option(
+        ...,
+        "--target",
+        help="""
+Target to monitor. Use 'ALL' for all resources. Must be 'ALL' for 'programs'.""",
+    ),
+    medium: str = typer.Option(
+        ...,
+        "--medium",
+        help="Medium used to send notifications. Must be 'slack' or 'discord'.",
+    ),
+    destination: str = typer.Option(
+        ..., "--destination", help="Destination webhook URL."
+    ),
+):
+    """
+    Create an notification to monitor on new resources, or changes to resources.
+
+    Currently only 'programs' is supported.
+    """
+
+    try:
+        notification = bb.create_notification(
+            resources=resources, target=target, medium=medium, destination=destination
+        )
+        typer.echo(f"Successfully created notification '{notification.id}'.")
+    except ApiResponseError as e:
+        typer.echo(e)
+        exit()
+
+
 @configure.command("key")
 def key_configure():
     path = PurePath.joinpath(Path.home(), ".bbrecon")
     token_path = PurePath.joinpath(path, "token")
     Path(path).mkdir(parents=True, exist_ok=True)
-    typer.echo("You can get a free API key from https://bugbountyrecon.com/")
+    typer.echo("You can get a free API key from https://console.bugbountyrecon.com/")
     token = typer.prompt("Enter your API key")
     with open(token_path, "w+") as f:
         print(token, file=f)
